pecos.qeccs.color\_488
======================

.. automodule:: pecos.qeccs.color_488



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.qeccs.color_488.circuit_implementation1
   pecos.qeccs.color_488.color_488
   pecos.qeccs.color_488.gates
   pecos.qeccs.color_488.instructions
